#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk
from gi.repository import GLib

# import threading

from openssl_gtk import app_info as info
from openssl_gtk import thread as thd

"""
Bu dosya hakkinda, sürüm notları, şifreleme ve şifre çözme gibi pencereleri içerir.

"""
	
def hakkinda(self, widget):
	self.hakkinda = Gtk.Window(title=(info.__appname__ + ' Hakkında'))
	self.hakkinda.connect("destroy", self.hakkinda.destroy)
	self.hakkinda.set_resizable(False)
	self.hakkinda.unmaximize()

	self.hakkinda.set_keep_above(True)
	self.hakkinda_grid = Gtk.Grid()
	self.hakkinda_grid.set_row_spacing(13)
	self.hakkinda_grid.set_border_width(25)
	self.hakkinda.add(self.hakkinda_grid)

	self.logo = Gtk.Image()
	self.logo.set_from_file(info.__logo__)

	self.ad = Gtk.Label()
	self.ad.set_markup('<span font_size="22000" color="#000"><b>' + info.__appname__ + '</b></span>')

	self.aciklama = Gtk.Label()
	self.aciklama.set_markup('<span font_size="13000" color="#000">' + info.__definition__ + '</span>')

	self.surum_durum = Gtk.Label()
	self.surum_durum.set_markup('<span font_size="12000" color="#000">' + info.__version__ + '-' + info.__status__ + '</span>')

	self.copyright = Gtk.Label() # 
	self.copyright.set_markup('<span font_size="11000" color="#272727"> ' + info.__copyright__+ '\n' + info.__email__ + '</span>')
	self.copyright.set_justify(Gtk.Justification.CENTER)

	self.lisans = Gtk.Label()
	self.lisans.set_markup('<span font_size="13000" color="#000">' + info.__appname__ + ' Hiç bir garanti vermez.\nKullanım amacı kullanıcının sorumluluğundadır\nDaha fazla bilgi için ' + info.__license__ + ' lisansını inceleyiniz.' + '</span>')
	self.lisans.set_justify(Gtk.Justification.CENTER)

	self.hakkinda_grid.add(self.logo)
	self.hakkinda_grid.attach(self.ad, 0, 1, 1, 1)
	self.hakkinda_grid.attach(self.aciklama, 0, 2, 1, 1)
	self.hakkinda_grid.attach(self.surum_durum, 0, 3, 1, 1)
	self.hakkinda_grid.attach(self.copyright, 0, 4, 1, 1)
	self.hakkinda_grid.attach(self.lisans, 0, 5, 1, 1)

	self.hakkinda.show_all()


def surum_notlari(self, widget):
	self.surum = Gtk.Window(title=info.__appname__ + ' ' + info.__version__ + ' Sürüm Notları')
	self.surum.connect("destroy", self.surum.destroy)
	self.surum.set_size_request(400, 370)
	# self.surum.set_position(Gtk.WindowPosition.CENTER) # Ekran ortalaması
	self.surum.set_resizable(False)
	self.surum.unmaximize()

	self.surum_grid = Gtk.Grid()
	self.surum_grid.set_row_spacing(3)
	self.surum_grid.set_border_width(5)
	self.surum.add(self.surum_grid)

	self.logo = Gtk.Image() # Resim eklendi
	self.logo.set_from_file(info.__logo__) #Resim belirtildi

	self.ad_surum = Gtk.Label()
	self.ad_surum.set_markup('<b> <big>'+info.__appname__ + ' ' + info.__version__+' Sürüm Notları</big></b> ')


	self.scroll = Gtk.ScrolledWindow() # Scroll oluşturuldu
	self.scroll.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC) # YATAY-DIKEY otomatikleştirildi
	self.scroll.set_size_request(400, 125)
	self.scroll.set_border_width(2)

	self.buffer = Gtk.TextBuffer() # Surum notları için buffer oluşturuldu
	self.buffer.set_text(info.surum_notlari) # Buffer'in içeriği değiştirildi

	self.text = Gtk.TextView(buffer=self.buffer) # Metin alanı oluşturuldu
	self.text.set_wrap_mode(Gtk.WrapMode.WORD) # WRAP değiştirildi
	self.text.set_editable(False) # Düzenleme kapatıldı

	self.scroll.add(self.text) # Scroll'a metin alanı eklendi.

	self.copyright = Gtk.Label()
	self.copyright.set_markup('<i><small>' + info.__copyright__ + '</small></i>')

	self.surum_grid.add(self.logo)
	self.surum_grid.attach(self.ad_surum, 0, 1, 1, 1)
	self.surum_grid.attach(self.scroll, 0, 2, 1, 1)
	self.surum_grid.attach(self.copyright, 0, 3, 1, 1)

	self.surum.show_all()

def dosya_sifreleme(self, widget):
	self.sifreleme = Gtk.Window(title='Dosya Şifreleniyor - ' + info.__appname__)
	self.sifreleme.set_resizable(False)
	self.sifreleme.set_size_request(300, 250)
	self.sifreleme.unmaximize()


	self.sifreleme_grid = Gtk.Grid()
	self.sifreleme.add(self.sifreleme_grid)
	self.sifreleme_grid.set_row_spacing(5)
	self.sifreleme_grid.set_border_width(5)

	
	self.baslik = Gtk.Label(label='Şifreleme işlemi başlıyor..')
	self.baslik.set_alignment(0, 0.5)

	self.progressbar = Gtk.ProgressBar()
	self.progressbar.activity_mode = False
	self.progressbar.set_fraction(0.0)

	self.scroll = Gtk.ScrolledWindow() 
	self.scroll.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
	self.scroll.set_size_request(450, 170)
	self.scroll.set_border_width(2)


	self.buffer = Gtk.TextBuffer() 

	self.text = Gtk.TextView(buffer=self.buffer) 
	self.text.set_wrap_mode(Gtk.WrapMode.WORD) 
	self.text.set_editable(False)

	self.scroll.add(self.text)

	self.kapat = Gtk.Button(label='Pencereyi Kapat')
	self.kapat.connect("clicked", self.sifreleme.destroy)
	self.kapat.set_sensitive(False)

	self.sifreleme_grid.add(self.baslik)
	self.sifreleme_grid.attach(self.progressbar, 0, 1, 1, 1)
	self.sifreleme_grid.attach(self.scroll, 0, 2 , 1, 1)
	self.sifreleme_grid.attach(self.kapat, 0, 3, 1, 1)

	self.sifreleme.show_all()

	GLib.idle_add(lambda: thd.sifreleme_thread(self, widget), priority=GLib.PRIORITY_HIGH)

	# thread = threading.Thread(target=thd.sifreleme_thread(self, widget))
	# thread.daemon = True
	# thread.start()

	

def sifre_cozme(self, widget):
	self.sifre_cozme = Gtk.Window(title='Dosya Şifresi Çözülüyor - ' + info.__appname__)
	self.sifre_cozme.set_resizable(False)
	self.sifre_cozme.set_size_request(300, 250)
	self.sifre_cozme.unmaximize()

	self.sifre_cozme_grid = Gtk.Grid()
	self.sifre_cozme.add(self.sifre_cozme_grid)
	self.sifre_cozme_grid.set_row_spacing(5)
	self.sifre_cozme_grid.set_border_width(5)


	self.baslik_coz = Gtk.Label(label="Şifre Çözme İşlemi Başlıyor..")
	self.baslik_coz.set_alignment(0, 0.5)

	self.progressbar_coz = Gtk.ProgressBar()
	self.progressbar_coz.activity_mode = False
	self.progressbar_coz.set_fraction(0.0)

	self.scroll_coz = Gtk.ScrolledWindow() 
	self.scroll_coz.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
	self.scroll_coz.set_size_request(450, 170)
	self.scroll_coz.set_border_width(2)


	self.buffer_coz = Gtk.TextBuffer()

	self.text_coz = Gtk.TextView(buffer=self.buffer_coz) 
	self.text_coz.set_wrap_mode(Gtk.WrapMode.WORD) 
	self.text_coz.set_editable(False)

	self.scroll_coz.add(self.text_coz)

	self.kapat_coz = Gtk.Button(label='Pencereyi Kapat')
	self.kapat_coz.connect("clicked", self.sifre_cozme.destroy)
	self.kapat_coz.set_sensitive(False)

	self.sifre_cozme_grid.add(self.baslik_coz)
	self.sifre_cozme_grid.attach(self.progressbar_coz, 0, 1, 1, 1)
	self.sifre_cozme_grid.attach(self.scroll_coz, 0, 2 , 1, 1)
	self.sifre_cozme_grid.attach(self.kapat_coz, 0, 3, 1, 1)

	self.sifre_cozme.show_all()

	GLib.idle_add(lambda: thd.sifre_cozme_thread(self, widget), priority=GLib.PRIORITY_HIGH)






#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Bu dosya uygulama thread'larını barındırır.
"""

import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk

from openssl_gtk import app_info as info
import os
import subprocess

def sifreleme_thread(self, widget):
	var = 0
	print ('Thread > Şifreleme başladı')
	print ('Thread > %s' % self.sifrelenecek_dosya)
	print ('Thread > %s' % self.cipher_secilen)
	print ('Thread > %s' % self.digest_secilen)

	self.end = self.buffer.get_end_iter() # Buffer metni çağırıldı
	self.buffer.insert(self.end, 'İşlem başlıyor..') # Buffer'a yeni metin eklendi.
	self.buffer.insert(self.end, '\n\nSeçilen dosya: ' + self.sifrelenecek_dosya)
	self.buffer.insert(self.end, '\nSeçilen Cipher: ' + self.cipher_secilen)
	self.buffer.insert(self.end, '\nSeçilen Digest: ' + self.digest_secilen)

	self.progressbar.set_fraction(20)

	self.komutS = '\nopenssl ' + self.cipher_secilen + ' -md ' + self.digest_secilen + ' -salt' + ' -a' + ' -in ' + self.sifrelenecek_dosya + ' -out ' + self.sifrelenecek_dosya + '.enc'

	print (self.komutS)

	self.buffer.insert(self.end, '\n' + self.komutS)
	self.baslik.set_text('Dosya Şifreleniyor..')


	if var == 0:
		self.progressbar.set_fraction(50)
		komut = subprocess.Popen(['openssl', self.cipher_secilen, '-md', self.digest_secilen, '-salt', '-a', '-k', self.parola_entry.get_text(), '-in', self.sifrelenecek_dosya, '-out', self.sifrelenecek_dosya + '.enc'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
		output, error = komut.communicate()
		self.progressbar.pulse()


		if komut.returncode == 0: # Hata yok
			self.baslik.set_text('Dosya Şifreleme Bitti :)')

			print ('OK: Durum >', komut.returncode)
			print (error)

			self.okunan = os.path.getsize(self.sifrelenecek_dosya)
			self.yazilan = os.path.getsize(self.sifrelenecek_dosya + '.enc')

			print ('\nOkunan boyut: ' + str(self.okunan) + '\nYazılan boyut: ' + str(self.yazilan))

			self.buffer.insert(self.end, '\n\nOkunan bayt: ' + str(self.okunan))
			self.buffer.insert(self.end, '\nYazılan bayt: ' + str(self.yazilan))
			self.buffer.insert(self.end, '\n\nBitti.')

			print ('\nThread> Bitti')
			self.kapat.set_sensitive(True)
			self.progressbar.set_fraction(100)
			var = +1

		elif komut.returncode == 1: # Hata var
			self.baslik.set_text('Dosya Şifrelenemedi :(')
			print (output, error)
			print ('İşlem hata ile sonlandı.')

			self.buffer.insert(self.end, '\n\n' + str(error))
			self.buffer.insert(self.end, '\n\n Hata ile bitti.')

			print ('\nThread> Hata ile bitti.')
			var = +1
			self.kapat.set_sensitive(True)
			self.progressbar.set_fraction(100)


def sifre_cozme_thread(self, widget):
	var = 0
	print ('Thread > Şifre çözme başladı')
	print ('Thread > %s' % self.cozulecek_dosya)
	print ('Thread > %s' % self.cipher_secilen_dec)
	print ('Thread > %s' % self.digest_secilen_dec)

	self.end2 = self.buffer_coz.get_end_iter() # Buffer metni çağırıldı
	self.buffer_coz.insert(self.end2, 'İşlem başlıyor..') # Buffer'a yeni metin eklendi.
	self.buffer_coz.insert(self.end2, '\n\nSeçilen dosya: ' + self.cozulecek_dosya)
	self.buffer_coz.insert(self.end2, '\nSeçilen Cipher: ' + self.cipher_secilen_dec)
	self.buffer_coz.insert(self.end2, '\nSeçilen Digest: ' + self.digest_secilen_dec)

	self.cozulecek_dosya_temizlenen = self.cozulecek_dosya.replace('.enc', '')

	self.progressbar_coz.set_fraction(20)

	self.komutS1 = '\nopenssl ' + self.cipher_secilen_dec + ' -md ' + self.digest_secilen_dec + ' -salt' + ' -d' + ' -a' + ' -in ' + self.cozulecek_dosya + ' -out ' + self.cozulecek_dosya_temizlenen

	print (self.komutS1)

	self.buffer_coz.insert(self.end2, '\n' + self.komutS1)
	self.baslik_coz.set_text('Dosya Şifreleniyor..')



	if var == 0:
		self.progressbar_coz.set_fraction(50)
		komut = subprocess.Popen(['openssl', self.cipher_secilen_dec, '-md', self.digest_secilen_dec, '-salt', '-d', '-a', '-k', self.parola_entry_dec.get_text(), '-in', self.cozulecek_dosya, '-out', self.cozulecek_dosya_temizlenen], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
		output, error = komut.communicate()
		self.progressbar_coz.pulse()


		if komut.returncode == 0: # Hata yok
			self.baslik_coz.set_text('Şifre Çözme Bitti :)')

			print ('OK: Durum >', komut.returncode)
			print (error)

			self.okunan = os.path.getsize(self.cozulecek_dosya)
			self.yazilan = os.path.getsize(self.cozulecek_dosya_temizlenen) # DİKKAT

			print ('\nOkunan boyut: ' + str(self.okunan) + '\nYazılan boyut: ' + str(self.yazilan))

			self.buffer_coz.insert(self.end2, '\n\nOkunan bayt: ' + str(self.okunan))
			self.buffer_coz.insert(self.end2, '\nYazılan bayt: ' + str(self.yazilan))
			self.buffer_coz.insert(self.end2, '\n\nBitti.')

			print ('\nThread> Bitti')
			self.kapat_coz.set_sensitive(True)
			self.progressbar_coz.set_fraction(100)
			var = +1

		elif komut.returncode == 1: # Hata var
			self.baslik_coz.set_text('Dosya Çözülemedi! :(')

			print (output, error)
			print ('İşlem hata ile sonlandı.')

			self.buffer_coz.insert(self.end2, '\n\n Dosya çözümlenemedi. Başlıca sebepleri şunlar olabilir:\n')
			self.buffer_coz.insert(self.end2, '* Cipher Yanlış\n* Digest Yanlış\n* Parola Yanlış\n* Şifreli dosya hasar görmüş.')
			self.buffer_coz.insert(self.end2, '\n\nBilgilerin doğru olduğuna eminseniz, geliştiriciden dosya çözümleme için yardım alabilirsiniz.')

			self.buffer_coz.insert(self.end2, '\n\n' + str(error))
			self.buffer_coz.insert(self.end2, '\n\n Hata ile bitti.')

			if os.path.isfile(self.cozulecek_dosya_temizlenen):
				os.remove(self.cozulecek_dosya_temizlenen)

			print ('\nThread> Hata ile bitti.')
			var = +1
			self.kapat_coz.set_sensitive(True)
			self.progressbar_coz.set_fraction(100)




#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk
from gi.repository import GLib

from openssl_gtk import window as pen
from openssl_gtk import app_info as info
from openssl_gtk import thread as thd


class GUI(Gtk.Window):
	def __init__(self):
		Gtk.Window.__init__(self, title=info.__appname__)
		self.connect("destroy", Gtk.main_quit)


		self.box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
		self.add(self.box)

		self.menu = Gtk.MenuBar() ## Menu

		self.filemenu = Gtk.Menu()
		self.file = Gtk.MenuItem(label="Dosya") 
		self.file.set_submenu(self.filemenu)

		self.exittab = Gtk.MenuItem(label="Kapat") 
		self.exittab.connect("activate", Gtk.main_quit)
		self.filemenu.append(self.exittab)

		self.helpmenu = Gtk.Menu() ## Yardım Menusu
		self.help = Gtk.MenuItem(label="Yardım")
		self.help.set_submenu(self.helpmenu)

		self.about = Gtk.MenuItem(label="Sürüm Notları") 
		self.about.connect("activate", self.surum_notlari)
		self.helpmenu.append(self.about)

		self.about = Gtk.MenuItem(label="Hakkında")
		self.about.connect("activate", self.hakkinda)
		self.helpmenu.append(self.about)

		self.menu.append(self.file)
		self.menu.append(self.help)

		self.notebook = Gtk.Notebook() # Notebook oluşturuldu


		self.box.pack_start(self.menu, False, False, 0)
		self.box.pack_start(self.notebook, False, False, 0)


		# Dosya Şifreleme Sekmesi
		self.page1 = Gtk.Grid() #column_homogeneous=True) # Hizalamak için box oluşturuldu.
		self.page1.set_border_width(15) # Kenar boşluğu eklendi
		self.page1.set_row_spacing(3) # Satır arasındaki boşluk ayarlandı
		self.page1.set_column_spacing(3) # Sutun arasındaki boşluk ayarlandı


		self.sifrelenecek_dosya = None
		self.dosya_metin = Gtk.Label(label='Dosya Seçimi')
		self.dosya_metin.set_alignment(0, 0.5) # Sola Hizalandı 

		self.dosya_entry = Gtk.Entry()
		self.dosya_entry.set_placeholder_text('Dosya Seçilmedi')
		self.dosya_entry.set_sensitive(False) # Entry kullanımı kaldırıldı

		self.dosya_buton = Gtk.Button(label='..')
		self.dosya_buton.connect('clicked', self.dosya_secim)

		self.cipher_secilen = None
		self.cipher_metin = Gtk.Label(label='Cipher Seçimi')
		self.cipher_metin.set_alignment(0, 0.5)

		self.cipher_list = Gtk.ComboBoxText()
		self.cipher_list.connect('changed', self.cipher_enc)
		for i in info.cipher_list:
			self.cipher_list.append_text(i)


		self.digest_secilen = None
		self.digest_metin = Gtk.Label(label='Digest Seçimi')
		self.digest_metin.set_alignment(0, 0.5)

		self.digest_list = Gtk.ComboBoxText()
		self.digest_list.connect('changed', self.digest_enc)
		for i in info.digest_list:
			self.digest_list.append_text(i)


		self.parola_metin = Gtk.Label(label='Parola Oluşturun')
		self.parola_metin.set_alignment(0, 0.5)
		self.parola_entry = Gtk.Entry()
		self.parola_entry.set_visibility(False)# Entry görünürlüğü kaldırıldı
		self.parola_entry.set_placeholder_text('Parola Giriniz')


		self.parola2_metin = Gtk.Label(label='Parolayı Yeniden Oluşturun')
		self.parola2_metin.set_alignment(0, 0.5)
		self.parola2_entry = Gtk.Entry()
		self.parola2_entry.set_visibility(False)
		self.parola2_entry.set_placeholder_text('Parolanızı Yeniden Giriniz')


		self.onay_buton = Gtk.Button(label='Dosyayı Şifrele')
		self.onay_buton.connect("clicked", self.sifreleme_kontrol) # Surum notu geçici


		self.page1.add(self.dosya_metin) # PAGE1 Grid alanı için yerleşim
		self.page1.attach(self.dosya_entry, 2, 0, 1, 1) # (WİDGET, YATAY-SIRA, DİKEY- SIRA, YATAY-HANGI-SUTUN-KAPSAYACAGI, DİKEY-GENİŞLİK)
		self.page1.attach(self.dosya_buton, 3, 0, 1, 1)

		self.page1.attach(self.cipher_metin, 0, 1, 1, 1)
		self.page1.attach(self.cipher_list, 2, 1, 2, 1)

		self.page1.attach(self.digest_metin, 0, 2, 2, 1)
		self.page1.attach(self.digest_list, 2, 2, 2, 1)

		self.page1.attach(self.parola_metin, 0, 3, 2, 1)
		self.page1.attach(self.parola_entry, 2, 3, 2, 1)

		self.page1.attach(self.parola2_metin, 0, 4, 2, 1)
		self.page1.attach(self.parola2_entry, 2, 4, 2, 1)
		self.page1.attach(self.onay_buton, 0, 5, 4 , 1)

		self.notebook.append_page(self.page1, Gtk.Label(label='Dosya Şifreleme')) # page1 Box'u NoteBook'a eklendi.


		# Dosya Şifre Çözme Sekmesi
		self.page2 = Gtk.Grid()

		self.page2.set_border_width(15) 
		self.page2.set_row_spacing(3)
		self.page2.set_column_spacing(3)


		self.cozulecek_dosya = None
		self.dosya_metin_dec = Gtk.Label(label='Şifrelenmiş Dosya Seçimi')
		self.dosya_metin_dec.set_alignment(0, 0.5)

		self.dosya_entry_dec = Gtk.Entry()
		self.dosya_entry_dec.set_placeholder_text('Dosya Seçilmedi')
		self.dosya_entry_dec.set_sensitive(False)

		self.dosya_entry_dec.set_editable(False)

		self.dosya_buton_dec = Gtk.Button(label='..')
		self.dosya_buton_dec.connect("clicked", self.dosya_secim_dec)

		self.cipher_secilen_dec = None
		self.cipher_metin_dec = Gtk.Label(label='Şifrelenmiş Cipher Seçimi')
		self.cipher_metin_dec.set_alignment(0, 0.5)

		self.cipher_list_dec = Gtk.ComboBoxText()
		self.cipher_list_dec.connect('changed', self.cipher_dec)
		for i in info.cipher_list:
			self.cipher_list_dec.append_text(i)

		self.digest_secilen_dec = None
		self.digest_metin_dec = Gtk.Label(label='Şifrelenmiş Digest Seçimi')
		self.digest_metin_dec.set_alignment(0, 0.5)

		self.digest_list_dec = Gtk.ComboBoxText()
		self.digest_list_dec.connect('changed', self.digest_dec)
		for i in info.digest_list:
			self.digest_list_dec.append_text(i)

		self.parola_metin_dec = Gtk.Label(label='Oluşturduğunuz Parola')
		self.parola_metin_dec.set_alignment(0, 0.5)
		self.parola_entry_dec = Gtk.Entry()
		self.parola_entry_dec.set_placeholder_text('Parolanızı giriniz')
		self.parola_entry_dec.set_visibility(False)

		self.onay_buton_dec = Gtk.Button(label='Dosyanın Şifresini Çöz')
		self.onay_buton_dec.connect("clicked", self.cozme_kontrol)


		self.page2.add(self.dosya_metin_dec)
		self.page2.attach(self.dosya_entry_dec, 2, 0, 1, 1)
		self.page2.attach(self.dosya_buton_dec, 3, 0, 1, 1)
		self.page2.attach(self.cipher_metin_dec, 0, 1, 1, 1)
		self.page2.attach(self.cipher_list_dec, 2, 1, 2, 1)
		self.page2.attach(self.digest_metin_dec, 0, 2, 1, 1)
		self.page2.attach(self.digest_list_dec, 2, 2, 2, 1)
		self.page2.attach(self.parola_metin_dec, 0, 3, 1, 1)
		self.page2.attach(self.parola_entry_dec, 2, 3, 2, 1)
		self.page2.attach(self.onay_buton_dec, 0, 4, 4, 1)

		self.notebook.append_page(self.page2, Gtk.Label(label='Dosya Çözme'))

	##
	# Şifreleme değişkenleri

	def dosya_secim(self, widget): # Şifrelenecek Dosyayı Seçme Penceresi
		filtre_tum_dosyalar = Gtk.FileFilter()
		filtre_tum_dosyalar.set_name("Tüm Dosyalar")
		filtre_tum_dosyalar.add_pattern("*")

		dialog = Gtk.FileChooserDialog("Şifrelemek istediğiniz dosyayı seçiniz",
		self, Gtk.FileChooserAction.OPEN,
		(
			Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
			Gtk.STOCK_OPEN, Gtk.ResponseType.OK
			)
		)

		dialog.add_filter(filtre_tum_dosyalar)

		yanit = dialog.run()
		if yanit == Gtk.ResponseType.OK:
			self.sifrelenecek_dosya = dialog.get_filename()
			print("Seçilen Dosya: " + self.sifrelenecek_dosya)
			self.dosya_entry.set_text(self.sifrelenecek_dosya)

		elif yanit == Gtk.ResponseType.CANCEL:
			pass

		dialog.destroy()

	def cipher_enc(self, widget):
		self.cipher_secilen = self.cipher_list.get_active_text()
		if self.cipher_secilen is not None:
			print('Seçilen Cipher: %s' % self.cipher_secilen)

		if self.cipher_secilen == 'aes-256-cbc (Önerilen)':
			self.cipher_secilen = self.cipher_secilen.replace(' (Önerilen)', '')

	def digest_enc(self, widget):
		self.digest_secilen = self.digest_list.get_active_text()
		if self.digest_secilen is not None:
			print('Seçilen Digest: %s' % self.digest_secilen)

		if self.digest_secilen == 'sha256 (Önerilen)':
			self.digest_secilen = self.digest_secilen.replace(' (Önerilen)', '')



	## 
	# Şifre çözme değişkenleri

	def dosya_secim_dec(self, widget): # Şifrelenecek Dosyayı Seçme Penceresi
		filtre_enc_dosyalar = Gtk.FileFilter()
		filtre_enc_dosyalar.set_name(info.__appname__ + ' Dosyaları (.enc)')
		filtre_enc_dosyalar.add_pattern("*.enc")

		dialog = Gtk.FileChooserDialog("Şifrelesini çözmek istediğiniz dosyayı seçiniz",
		self, Gtk.FileChooserAction.OPEN,
		(
			Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
			Gtk.STOCK_OPEN, Gtk.ResponseType.OK
			)
		)

		dialog.add_filter(filtre_enc_dosyalar)

		yanit = dialog.run()
		if yanit == Gtk.ResponseType.OK:
			self.cozulecek_dosya = dialog.get_filename()
			print("Şifresi Çözülecek Dosya: " + self.cozulecek_dosya)
			self.dosya_entry_dec.set_text(self.cozulecek_dosya)

		elif yanit == Gtk.ResponseType.CANCEL:
			pass

		dialog.destroy()


	def cipher_dec(self, widget):
		self.cipher_secilen_dec = self.cipher_list_dec.get_active_text()
		if self.cipher_secilen_dec is not None:
			print ('Şifresi çözülmek istenen Cipher: %s' % self.cipher_secilen_dec)

		if self.cipher_secilen_dec == 'aes-256-cbc (Önerilen)':
			self.cipher_secilen_dec = self.cipher_secilen_dec.replace(' (Önerilen)', '')



	def digest_dec(self, widget):
		self.digest_secilen_dec = self.digest_list_dec.get_active_text()
		if self.digest_secilen_dec is not None:
			print ('Şifresi	çözülmek istenen Digest: %s' % self.digest_secilen_dec)

		if self.digest_secilen_dec == 'sha256 (Önerilen)':
			self.digest_secilen_dec = self.digest_secilen_dec.replace(' (Önerilen)', '')

	

	## Uyarı mesajları ve kontrol fonksiyonları
	# Şifreleme kontrol
	def sifreleme_kontrol(self, widget):
		var = 0
		if self.sifrelenecek_dosya == None:
			print ('Dosya Seçilmedi')

			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Herhangi bir Dosya seçmediniz?\nBu işlem bir dosyaya ihtiyaç duyar!")
			dialog.run()
			var = +1
			dialog.destroy()

		if self.cipher_secilen == None:
			print ('Cipher Seçilmedi')
			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Herhangi bir Cipher seçmediniz?\nBu işlem Cipher seçimine ihtiyaç duyar!")
			dialog.run()
			var = +1
			dialog.destroy()

		if self.digest_secilen == None:
			print ('Digest Seçilmedi')
			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Herhangi bir Digest seçmediniz?\nBu işlem Digest seçimine ihtiyaç duyar!")
			dialog.run()
			var = +1
			dialog.destroy()

		if self.parola_entry.get_text() == '':
			print ('Parola oluşturulmadı')
			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Parola alanı boş olamaz?\nLütfen bir porola oluşturun!")
			dialog.run()
			var = +1
			dialog.destroy()

		if self.parola_entry.get_text() != self.parola2_entry.get_text():
			print ('Parolalar aynı değil')
			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Parolalar aynı değil?\nLütfen parolaları dikkatlice yeniden oluşturun!")
			dialog.run()
			var = +1
			dialog.destroy()

		if self.parola_entry.get_text() == self.parola2_entry.get_text():
			print ('Parola aynı. OK')
			self.parola = self.parola_entry.get_text()


		if var == 0:
			pen.dosya_sifreleme(self, widget)

	# Şifre Çözme Kontrol
	def cozme_kontrol(self, widget):
		var = 0
		if self.cozulecek_dosya == None:
			print ('Dosya Seçilmedi')

			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Herhangi bir Dosya seçmediniz?\nBu işlem bir dosyaya ihtiyaç duyar!")
			dialog.run()
			var = +1
			dialog.destroy()


		if self.cipher_secilen_dec == None:
			print ('Cipher Seçilmedi')
			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Herhangi bir Cipher seçmediniz?\nBu işlem Cipher seçimine ihtiyaç duyar!")
			dialog.run()
			var = +1
			dialog.destroy()

		if self.digest_secilen_dec == None:
			print ('Digest Seçilmedi')
			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Herhangi bir Digest seçmediniz?\nBu işlem Digest seçimine ihtiyaç duyar!")
			dialog.run()
			var = +1
			dialog.destroy()

		if self.parola_entry_dec.get_text() == '':
			print ('Parola oluşturulmadı')
			dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.CANCEL, "Bir hatayla karşılaşıldı")
			dialog.format_secondary_text("Parola alanı boş olamaz?\nLütfen bir porola oluşturun!")
			dialog.run()
			var = +1
			dialog.destroy()
		
		if var == 0:
			pen.sifre_cozme(self, widget)


	# Sürüm notları penceresi
	def surum_notlari(self, widget):
		pen.surum_notlari(self, widget)

	# Hakkında penceresi
	def hakkinda(self, widget):
		pen.hakkinda(self, widget)


if __name__ == "__main__":
	window = GUI()
	window.show_all()
	Gtk.main()


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="openssl-gtk",
    version="1.0.2",
    author="Muhammed Çamsarı",
    license='MIT',
    author_email="Muhammedcamsari@icloud.com",
    description="Perform your Openssl operations without using a terminal.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/muhammedcamsari/openssl-gtk",
    keywords=['openssl', 'openssl-gui', 'security', 'encrypt'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: End Users/Desktop",
        "Topic :: Desktop Environment :: Gnome",
        "Natural Language :: Turkish",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    scripts=["openssl-gui.py"],
    packages = ['openssl_gtk'],
)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Bu dosya uygulama hakkında bilgi tutan değişkenleri içerir.
"""

__author__ = "Muhammed Çamsarı"
__appname__ = "OpenSSL-GTK"
__definition__ = "Terminal kullanmadan Openssl işlemlerinizi gerçekleştirin."
__legalnote__ = __appname__ + ' hiçbir garanti vermez.\nKullanım amacı tamamen kullanıcının sorumluluğundadır.\nDaha fazla bilgi için MIT lisansını inceleyiniz.'
__copyright__ = "Copyright (c) 2019 " + __author__
__license__ = "MIT"
__version__ = "1.0.2"
__status__ = "Beta"
__email__ = "muhammedcamsari@icloud.com"
__pgp__ = 'F294 1D36 A8C8 101B EEB0  16A7 B260 DBA5 2DAA 962A'
__logo__ = 'openssl_gtk/logo.png'

cipher_list = ['aes-128-cbc', 'aes-128-ecb', 'aes-192-cbc', 'aes-192-ecb', 'aes-256-cbc (Önerilen)', 'aes-256-ecb']
digest_list = ['md5', 'md_gost94', 'ripemd160', 'sha1', 'sha224', 'sha256 (Önerilen)', 'sha384', 'sha512', 'streebog256', 'streebog512', 'whirlpool']

surum_notlari = """
 * Bu sürüm itibariyle, Openssl enc modeliyle dosyalarınızı şifreleyebilecek ve şifresini çözebileceksiniz.

Bu beta sürüm ve hatayla karşılaşılma olasılığı oldukça yüksek.
Lütfen karşılaştığınız hataları geliştiriye bildirin: muhammedcamsari@icloud.com
"""
